/// <reference types="node" />
import { Stream } from 'stream';
import { Dialog, View, KnownBlock, Block, MessageAttachment, LinkUnfurls, CallUser } from '@slack/types';
import { WebAPICallOptions, WebAPICallResult, WebClientEvent } from './WebClient';
import { EventEmitter } from 'eventemitter3';
/**
 * A class that defines all Web API methods, their arguments type, their response type, and binds those methods to the
 * `apiCall` class method.
 */
export declare abstract class Methods extends EventEmitter<WebClientEvent> {
    protected constructor();
    abstract apiCall(method: string, options?: WebAPICallOptions): Promise<WebAPICallResult>;
    readonly admin: {
        apps: {
            approve: Method<AdminAppsApproveArguments, WebAPICallResult>;
            approved: {
                list: Method<AdminAppsApprovedListArguments, WebAPICallResult>;
            };
            requests: {
                list: Method<AdminAppsRequestsListArguments, WebAPICallResult>;
            };
            restrict: Method<AdminAppsRestrictArguments, WebAPICallResult>;
            restricted: {
                list: Method<AdminAppsRestrictedListArguments, WebAPICallResult>;
            };
        };
        barriers: {
            create: Method<AdminBarriersCreateArguments, WebAPICallResult>;
            delete: Method<AdminBarriersDeleteArguments, WebAPICallResult>;
            list: Method<AdminBarriersListArguments, WebAPICallResult>;
            update: Method<AdminBarriersUpdateArguments, WebAPICallResult>;
        };
        conversations: {
            archive: Method<AdminConversationsArchiveArguments, WebAPICallResult>;
            convertToPrivate: Method<AdminConversationsConvertToPrivateArguments, WebAPICallResult>;
            create: Method<AdminConversationsCreateArguments, WebAPICallResult>;
            delete: Method<AdminConversationsDeleteArguments, WebAPICallResult>;
            disconnectShared: Method<AdminConversationsDisconnectSharedArguments, WebAPICallResult>;
            ekm: {
                listOriginalConnectedChannelInfo: Method<AdminConversationsEKMListOriginalConnectedChannelInfoArguments, WebAPICallResult>;
            };
            getConversationPrefs: Method<AdminConversationsGetConversationPrefsArguments, WebAPICallResult>;
            getTeams: Method<AdminConversationsGetTeamsArguments, WebAPICallResult>;
            invite: Method<AdminConversationsInviteArguments, WebAPICallResult>;
            rename: Method<AdminConversationsRenameArguments, WebAPICallResult>;
            restrictAccess: {
                addGroup: Method<AdminConversationsRestrictAccessAddGroupArguments, WebAPICallResult>;
                listGroups: Method<AdminConversationsRestrictAccessListGroupsArguments, WebAPICallResult>;
                removeGroup: Method<AdminConversationsRestrictAccessRemoveGroupArguments, WebAPICallResult>;
            };
            search: Method<AdminConversationsSearchArguments, WebAPICallResult>;
            setConversationPrefs: Method<AdminConversationsSetConversationPrefsArguments, WebAPICallResult>;
            setTeams: Method<AdminConversationsSetTeamsArguments, WebAPICallResult>;
            unarchive: Method<AdminConversationsUnarchiveArguments, WebAPICallResult>;
        };
        emoji: {
            add: Method<AdminEmojiAddArguments, WebAPICallResult>;
            addAlias: Method<AdminEmojiAddAliasArguments, WebAPICallResult>;
            list: Method<AdminEmojiListArguments, WebAPICallResult>;
            remove: Method<AdminEmojiRemoveArguments, WebAPICallResult>;
            rename: Method<AdminEmojiRenameArguments, WebAPICallResult>;
        };
        inviteRequests: {
            approve: Method<AdminInviteRequestsApproveArguments, WebAPICallResult>;
            approved: {
                list: Method<AdminInviteRequestsApprovedListArguments, WebAPICallResult>;
            };
            denied: {
                list: Method<AdminInviteRequestsDeniedListArguments, WebAPICallResult>;
            };
            deny: Method<AdminInviteRequestsDenyArguments, WebAPICallResult>;
            list: Method<AdminInviteRequestsListArguments, WebAPICallResult>;
        };
        teams: {
            admins: {
                list: Method<AdminTeamsAdminsListArguments, WebAPICallResult>;
            };
            create: Method<AdminTeamsCreateArguments, WebAPICallResult>;
            list: Method<AdminTeamsListArguments, WebAPICallResult>;
            owners: {
                list: Method<AdminTeamsOwnersListArguments, WebAPICallResult>;
            };
            settings: {
                info: Method<AdminTeamsSettingsInfoArguments, WebAPICallResult>;
                setDefaultChannels: Method<AdminTeamsSettingsSetDefaultChannelsArguments, WebAPICallResult>;
                setDescription: Method<AdminTeamsSettingsSetDescriptionArguments, WebAPICallResult>;
                setDiscoverability: Method<AdminTeamsSettingsSetDiscoverabilityArguments, WebAPICallResult>;
                setIcon: Method<AdminTeamsSettingsSetIconArguments, WebAPICallResult>;
                setName: Method<AdminTeamsSettingsSetNameArguments, WebAPICallResult>;
            };
        };
        usergroups: {
            addChannels: Method<AdminUsergroupsAddChannelsArguments, WebAPICallResult>;
            addTeams: Method<AdminUsergroupsAddTeamsArguments, WebAPICallResult>;
            listChannels: Method<AdminUsergroupsListChannelsArguments, WebAPICallResult>;
            removeChannels: Method<AdminUsergroupsRemoveChannelsArguments, WebAPICallResult>;
        };
        users: {
            assign: Method<AdminUsersAssignArguments, WebAPICallResult>;
            invite: Method<AdminUsersInviteArguments, WebAPICallResult>;
            list: Method<AdminUsersListArguments, WebAPICallResult>;
            remove: Method<AdminUsersRemoveArguments, WebAPICallResult>;
            session: {
                list: Method<AdminUsersSessionListArguments, WebAPICallResult>;
                reset: Method<AdminUsersSessionResetArguments, WebAPICallResult>;
                invalidate: Method<AdminUsersSessionInvalidateArguments, WebAPICallResult>;
            };
            setAdmin: Method<AdminUsersSetAdminArguments, WebAPICallResult>;
            setExpiration: Method<AdminUsersSetExpirationArguments, WebAPICallResult>;
            setOwner: Method<AdminUsersSetOwnerArguments, WebAPICallResult>;
            setRegular: Method<AdminUsersSetRegularArguments, WebAPICallResult>;
        };
    };
    readonly api: {
        test: Method<APITestArguments, WebAPICallResult>;
    };
    readonly apps: {
        event: {
            authorizations: {
                list: Method<AppsEventAuthorizationsListArguments, WebAPICallResult>;
            };
        };
        uninstall: Method<AppsUninstallArguments, WebAPICallResult>;
    };
    readonly auth: {
        revoke: Method<AuthRevokeArguments, WebAPICallResult>;
        teams: {
            list: Method<AuthTeamsListArguments, WebAPICallResult>;
        };
        test: Method<AuthTestArguments, WebAPICallResult>;
    };
    readonly bots: {
        info: Method<BotsInfoArguments, WebAPICallResult>;
    };
    readonly calls: {
        add: Method<CallsAddArguments, WebAPICallResult>;
        end: Method<CallsEndArguments, WebAPICallResult>;
        info: Method<CallsInfoArguments, WebAPICallResult>;
        update: Method<CallsUpdateArguments, WebAPICallResult>;
        participants: {
            add: Method<CallsParticipantsAddArguments, WebAPICallResult>;
            remove: Method<CallsParticipantsRemoveArguments, WebAPICallResult>;
        };
    };
    readonly channels: {
        archive: Method<ChannelsArchiveArguments, WebAPICallResult>;
        create: Method<ChannelsCreateArguments, WebAPICallResult>;
        history: Method<ChannelsHistoryArguments, WebAPICallResult>;
        info: Method<ChannelsInfoArguments, WebAPICallResult>;
        invite: Method<ChannelsInviteArguments, WebAPICallResult>;
        join: Method<ChannelsJoinArguments, WebAPICallResult>;
        kick: Method<ChannelsKickArguments, WebAPICallResult>;
        leave: Method<ChannelsLeaveArguments, WebAPICallResult>;
        list: Method<ChannelsListArguments, WebAPICallResult>;
        mark: Method<ChannelsMarkArguments, WebAPICallResult>;
        rename: Method<ChannelsRenameArguments, WebAPICallResult>;
        replies: Method<ChannelsRepliesArguments, WebAPICallResult>;
        setPurpose: Method<ChannelsSetPurposeArguments, WebAPICallResult>;
        setTopic: Method<ChannelsSetTopicArguments, WebAPICallResult>;
        unarchive: Method<ChannelsUnarchiveArguments, WebAPICallResult>;
    };
    readonly chat: {
        delete: Method<ChatDeleteArguments, WebAPICallResult>;
        deleteScheduledMessage: Method<ChatDeleteScheduledMessageArguments, WebAPICallResult>;
        getPermalink: Method<ChatGetPermalinkArguments, WebAPICallResult>;
        meMessage: Method<ChatMeMessageArguments, WebAPICallResult>;
        postEphemeral: Method<ChatPostEphemeralArguments, WebAPICallResult>;
        postMessage: Method<ChatPostMessageArguments, WebAPICallResult>;
        scheduleMessage: Method<ChatScheduleMessageArguments, WebAPICallResult>;
        scheduledMessages: {
            list: Method<ChatScheduledMessagesListArguments, WebAPICallResult>;
        };
        unfurl: Method<ChatUnfurlArguments, WebAPICallResult>;
        update: Method<ChatUpdateArguments, WebAPICallResult>;
    };
    readonly conversations: {
        archive: Method<ConversationsArchiveArguments, WebAPICallResult>;
        close: Method<ConversationsCloseArguments, WebAPICallResult>;
        create: Method<ConversationsCreateArguments, WebAPICallResult>;
        history: Method<ConversationsHistoryArguments, WebAPICallResult>;
        info: Method<ConversationsInfoArguments, WebAPICallResult>;
        invite: Method<ConversationsInviteArguments, WebAPICallResult>;
        join: Method<ConversationsJoinArguments, WebAPICallResult>;
        kick: Method<ConversationsKickArguments, WebAPICallResult>;
        leave: Method<ConversationsLeaveArguments, WebAPICallResult>;
        list: Method<ConversationsListArguments, WebAPICallResult>;
        mark: Method<ConversationsMarkArguments, WebAPICallResult>;
        members: Method<ConversationsMembersArguments, WebAPICallResult>;
        open: Method<ConversationsOpenArguments, WebAPICallResult>;
        rename: Method<ConversationsRenameArguments, WebAPICallResult>;
        replies: Method<ConversationsRepliesArguments, WebAPICallResult>;
        setPurpose: Method<ConversationsSetPurposeArguments, WebAPICallResult>;
        setTopic: Method<ConversationsSetTopicArguments, WebAPICallResult>;
        unarchive: Method<ConversationsUnarchiveArguments, WebAPICallResult>;
    };
    readonly views: {
        open: Method<ViewsOpenArguments, WebAPICallResult>;
        publish: Method<ViewsPublishArguments, WebAPICallResult>;
        push: Method<ViewsPushArguments, WebAPICallResult>;
        update: Method<ViewsUpdateArguments, WebAPICallResult>;
    };
    readonly dialog: {
        open: Method<DialogOpenArguments, WebAPICallResult>;
    };
    readonly dnd: {
        endDnd: Method<DndEndDndArguments, WebAPICallResult>;
        endSnooze: Method<DndEndSnoozeArguments, WebAPICallResult>;
        info: Method<DndInfoArguments, WebAPICallResult>;
        setSnooze: Method<DndSetSnoozeArguments, WebAPICallResult>;
        teamInfo: Method<DndTeamInfoArguments, WebAPICallResult>;
    };
    readonly emoji: {
        list: Method<EmojiListArguments, WebAPICallResult>;
    };
    readonly files: {
        delete: Method<FilesDeleteArguments, WebAPICallResult>;
        info: Method<FilesInfoArguments, WebAPICallResult>;
        list: Method<FilesListArguments, WebAPICallResult>;
        revokePublicURL: Method<FilesRevokePublicURLArguments, WebAPICallResult>;
        sharedPublicURL: Method<FilesSharedPublicURLArguments, WebAPICallResult>;
        upload: Method<FilesUploadArguments, WebAPICallResult>;
        comments: {
            delete: Method<FilesCommentsDeleteArguments, WebAPICallResult>;
        };
        remote: {
            info: Method<FilesRemoteInfoArguments, WebAPICallResult>;
            list: Method<FilesRemoteListArguments, WebAPICallResult>;
            add: Method<FilesRemoteAddArguments, WebAPICallResult>;
            update: Method<FilesRemoteUpdateArguments, WebAPICallResult>;
            remove: Method<FilesRemoteRemoveArguments, WebAPICallResult>;
            share: Method<FilesRemoteShareArguments, WebAPICallResult>;
        };
    };
    readonly groups: {
        archive: Method<GroupsArchiveArguments, WebAPICallResult>;
        create: Method<GroupsCreateArguments, WebAPICallResult>;
        createChild: Method<GroupsCreateChildArguments, WebAPICallResult>;
        history: Method<GroupsHistoryArguments, WebAPICallResult>;
        info: Method<GroupsInfoArguments, WebAPICallResult>;
        invite: Method<GroupsInviteArguments, WebAPICallResult>;
        kick: Method<GroupsKickArguments, WebAPICallResult>;
        leave: Method<GroupsLeaveArguments, WebAPICallResult>;
        list: Method<GroupsListArguments, WebAPICallResult>;
        mark: Method<GroupsMarkArguments, WebAPICallResult>;
        open: Method<GroupsOpenArguments, WebAPICallResult>;
        rename: Method<GroupsRenameArguments, WebAPICallResult>;
        replies: Method<GroupsRepliesArguments, WebAPICallResult>;
        setPurpose: Method<GroupsSetPurposeArguments, WebAPICallResult>;
        setTopic: Method<GroupsSetTopicArguments, WebAPICallResult>;
        unarchive: Method<GroupsUnarchiveArguments, WebAPICallResult>;
    };
    readonly im: {
        close: Method<IMCloseArguments, WebAPICallResult>;
        history: Method<IMHistoryArguments, WebAPICallResult>;
        list: Method<IMListArguments, WebAPICallResult>;
        mark: Method<IMMarkArguments, WebAPICallResult>;
        open: Method<IMOpenArguments, WebAPICallResult>;
        replies: Method<IMRepliesArguments, WebAPICallResult>;
    };
    readonly migration: {
        exchange: Method<MigrationExchangeArguments, WebAPICallResult>;
    };
    readonly mpim: {
        close: Method<MPIMCloseArguments, WebAPICallResult>;
        history: Method<MPIMHistoryArguments, WebAPICallResult>;
        list: Method<MPIMListArguments, WebAPICallResult>;
        mark: Method<MPIMMarkArguments, WebAPICallResult>;
        open: Method<MPIMOpenArguments, WebAPICallResult>;
        replies: Method<MPIMRepliesArguments, WebAPICallResult>;
    };
    readonly oauth: {
        access: Method<OAuthAccessArguments, WebAPICallResult>;
        v2: {
            access: Method<OAuthV2AccessArguments, WebAPICallResult>;
        };
    };
    readonly pins: {
        add: Method<PinsAddArguments, WebAPICallResult>;
        list: Method<PinsListArguments, WebAPICallResult>;
        remove: Method<PinsRemoveArguments, WebAPICallResult>;
    };
    readonly reactions: {
        add: Method<ReactionsAddArguments, WebAPICallResult>;
        get: Method<ReactionsGetArguments, WebAPICallResult>;
        list: Method<ReactionsListArguments, WebAPICallResult>;
        remove: Method<ReactionsRemoveArguments, WebAPICallResult>;
    };
    readonly reminders: {
        add: Method<RemindersAddArguments, WebAPICallResult>;
        complete: Method<RemindersCompleteArguments, WebAPICallResult>;
        delete: Method<RemindersDeleteArguments, WebAPICallResult>;
        info: Method<RemindersInfoArguments, WebAPICallResult>;
        list: Method<RemindersListArguments, WebAPICallResult>;
    };
    readonly rtm: {
        connect: Method<RTMConnectArguments, WebAPICallResult>;
        start: Method<RTMStartArguments, WebAPICallResult>;
    };
    readonly search: {
        all: Method<SearchAllArguments, WebAPICallResult>;
        files: Method<SearchFilesArguments, WebAPICallResult>;
        messages: Method<SearchMessagesArguments, WebAPICallResult>;
    };
    readonly stars: {
        add: Method<StarsAddArguments, WebAPICallResult>;
        list: Method<StarsListArguments, WebAPICallResult>;
        remove: Method<StarsRemoveArguments, WebAPICallResult>;
    };
    readonly team: {
        accessLogs: Method<TeamAccessLogsArguments, WebAPICallResult>;
        billableInfo: Method<TeamBillableInfoArguments, WebAPICallResult>;
        info: Method<TeamInfoArguments, WebAPICallResult>;
        integrationLogs: Method<TeamIntegrationLogsArguments, WebAPICallResult>;
        profile: {
            get: Method<TeamProfileGetArguments, WebAPICallResult>;
        };
    };
    readonly usergroups: {
        create: Method<UsergroupsCreateArguments, WebAPICallResult>;
        disable: Method<UsergroupsDisableArguments, WebAPICallResult>;
        enable: Method<UsergroupsEnableArguments, WebAPICallResult>;
        list: Method<UsergroupsListArguments, WebAPICallResult>;
        update: Method<UsergroupsUpdateArguments, WebAPICallResult>;
        users: {
            list: Method<UsergroupsUsersListArguments, WebAPICallResult>;
            update: Method<UsergroupsUsersUpdateArguments, WebAPICallResult>;
        };
    };
    readonly users: {
        conversations: Method<UsersConversationsArguments, WebAPICallResult>;
        deletePhoto: Method<UsersDeletePhotoArguments, WebAPICallResult>;
        getPresence: Method<UsersGetPresenceArguments, WebAPICallResult>;
        identity: Method<UsersIdentityArguments, WebAPICallResult>;
        info: Method<UsersInfoArguments, WebAPICallResult>;
        list: Method<UsersListArguments, WebAPICallResult>;
        lookupByEmail: Method<UsersLookupByEmailArguments, WebAPICallResult>;
        setPhoto: Method<UsersSetPhotoArguments, WebAPICallResult>;
        setPresence: Method<UsersSetPresenceArguments, WebAPICallResult>;
        profile: {
            get: Method<UsersProfileGetArguments, WebAPICallResult>;
            set: Method<UsersProfileSetArguments, WebAPICallResult>;
        };
    };
    readonly workflows: {
        stepCompleted: Method<WorkflowsStepCompletedArguments, WebAPICallResult>;
        stepFailed: Method<WorkflowsStepFailedArguments, WebAPICallResult>;
        updateStep: Method<WorkflowsUpdateStepArguments, WebAPICallResult>;
    };
}
/**
 * Generic method definition
 */
export default interface Method<MethodArguments extends WebAPICallOptions, MethodResult extends WebAPICallResult = WebAPICallResult> {
    (options?: MethodArguments): Promise<MethodResult>;
}
export interface TokenOverridable {
    token?: string;
}
export interface LocaleAware {
    include_locale?: boolean;
}
export interface Searchable {
    query: string;
    highlight?: boolean;
    sort: 'score' | 'timestamp';
    sort_dir: 'asc' | 'desc';
    team_id?: string;
}
export declare const cursorPaginationEnabledMethods: Set<string>;
export interface CursorPaginationEnabled {
    limit?: number;
    cursor?: string;
}
export interface TimelinePaginationEnabled {
    oldest?: string;
    latest?: string;
    inclusive?: boolean;
}
export interface TraditionalPagingEnabled {
    page?: number;
    count?: number;
}
export interface AdminAppsApproveArguments extends WebAPICallOptions, TokenOverridable {
    app_id?: string;
    request_id?: string;
    team_id?: string;
}
export interface AdminAppsApprovedListArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
    team_id?: string;
    enterprise_id?: string;
}
export interface AdminAppsRequestsListArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
    team_id?: string;
}
export interface AdminAppsRestrictArguments extends WebAPICallOptions, TokenOverridable {
    app_id?: string;
    request_id?: string;
    team_id?: string;
}
export interface AdminAppsRestrictedListArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
    team_id?: string;
    enterprise_id?: string;
}
export interface AdminBarriersCreateArguments extends WebAPICallOptions, TokenOverridable {
    barriered_from_usergroup_ids: string[];
    primary_usergroup_id: string;
    restricted_subjects: string[];
}
export interface AdminBarriersDeleteArguments extends WebAPICallOptions, TokenOverridable {
    barrier_id: string;
}
export interface AdminBarriersListArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
}
export interface AdminBarriersUpdateArguments extends WebAPICallOptions, TokenOverridable {
    barrier_id: string;
    barriered_from_usergroup_ids: string[];
    primary_usergroup_id: string;
    restricted_subjects: string[];
}
export interface AdminConversationsArchiveArguments extends WebAPICallOptions, TokenOverridable {
    channel_id: string;
}
export interface AdminConversationsConvertToPrivateArguments extends WebAPICallOptions, TokenOverridable {
    channel_id: string;
}
export interface AdminConversationsCreateArguments extends WebAPICallOptions, TokenOverridable {
    is_private: boolean;
    name: string;
    description?: string;
    org_wide?: boolean;
    team_id?: string;
}
export interface AdminConversationsDeleteArguments extends WebAPICallOptions, TokenOverridable {
    channel_id: string;
}
export interface AdminConversationsDisconnectSharedArguments extends WebAPICallOptions, TokenOverridable {
    channel_id: string;
    leaving_team_ids?: string[];
}
export interface AdminConversationsEKMListOriginalConnectedChannelInfoArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
    channel_ids?: string[];
    team_ids?: string[];
}
export interface AdminConversationsGetConversationPrefsArguments extends WebAPICallOptions, TokenOverridable {
    channel_id: string;
}
export interface AdminConversationsGetTeamsArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
    channel_id: string;
}
export interface AdminConversationsInviteArguments extends WebAPICallOptions, TokenOverridable {
    channel_id: string;
    user_ids: string[];
}
export interface AdminConversationsRenameArguments extends WebAPICallOptions, TokenOverridable {
    channel_id: string;
    name: string;
}
export interface AdminConversationsRestrictAccessAddGroupArguments extends WebAPICallOptions, TokenOverridable {
    channel_id: string;
    group_id: string;
    team_id?: string;
}
export interface AdminConversationsRestrictAccessListGroupsArguments extends WebAPICallOptions, TokenOverridable {
    channel_id: string;
    team_id?: string;
}
export interface AdminConversationsRestrictAccessRemoveGroupArguments extends WebAPICallOptions, TokenOverridable {
    channel_id: string;
    group_id: string;
    team_id: string;
}
export interface AdminConversationsSearchArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
    query?: string;
    search_channel_types?: string[];
    sort?: 'relevant' | 'name' | 'member_count' | 'created';
    sort_dir?: 'asc' | 'desc';
    team_ids?: string[];
}
export interface AdminConversationsSetConversationPrefsArguments extends WebAPICallOptions, TokenOverridable {
    channel_id: string;
    prefs: object;
}
export interface AdminConversationsSetTeamsArguments extends WebAPICallOptions, TokenOverridable {
    channel_id: string;
    team_id?: string;
    target_team_ids?: string[];
    org_channel?: boolean;
}
export interface AdminConversationsUnarchiveArguments extends WebAPICallOptions, TokenOverridable {
    channel_id: string;
}
export interface AdminEmojiAddArguments extends WebAPICallOptions, TokenOverridable {
    name: string;
    url: string;
}
export interface AdminEmojiAddAliasArguments extends WebAPICallOptions, TokenOverridable {
    name: string;
    alias_for: string;
}
export interface AdminEmojiListArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
}
export interface AdminEmojiRemoveArguments extends WebAPICallOptions, TokenOverridable {
    name: string;
}
export interface AdminEmojiRenameArguments extends WebAPICallOptions, TokenOverridable {
    name: string;
    new_name: string;
}
export interface AdminInviteRequestsApproveArguments extends WebAPICallOptions, TokenOverridable {
    invite_request_id: string;
    team_id: string;
}
export interface AdminInviteRequestsApprovedListArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
    team_id: string;
}
export interface AdminInviteRequestsDenyArguments extends WebAPICallOptions, TokenOverridable {
    invite_request_id: string;
    team_id: string;
}
export interface AdminInviteRequestsDeniedListArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
    team_id: string;
}
export interface AdminInviteRequestsListArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
    team_id: string;
}
export interface AdminTeamsAdminsListArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
    team_id: string;
}
export interface AdminTeamsCreateArguments extends WebAPICallOptions, TokenOverridable {
    team_domain: string;
    team_name: string;
    team_description?: string;
    team_discoverability?: string;
}
export interface AdminTeamsListArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
}
export interface AdminTeamsOwnersListArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
    team_id: string;
}
export interface AdminTeamsSettingsInfoArguments extends WebAPICallOptions, TokenOverridable {
    team_id: string;
}
export interface AdminTeamsSettingsSetDefaultChannelsArguments extends WebAPICallOptions, TokenOverridable {
    team_id: string;
    channel_ids: string[];
}
export interface AdminTeamsSettingsSetDescriptionArguments extends WebAPICallOptions, TokenOverridable {
    team_id: string;
    description: string;
}
export interface AdminTeamsSettingsSetDiscoverabilityArguments extends WebAPICallOptions, TokenOverridable {
    team_id: string;
    discoverability: 'open' | 'invite_only' | 'closed' | 'unlisted';
}
export interface AdminTeamsSettingsSetIconArguments extends WebAPICallOptions, TokenOverridable {
    team_id: string;
    image_url: string;
}
export interface AdminTeamsSettingsSetNameArguments extends WebAPICallOptions, TokenOverridable {
    team_id: string;
    name: string;
}
export interface AdminUsergroupsAddChannelsArguments extends WebAPICallOptions, TokenOverridable {
    usergroup_id: string;
    team_id?: string;
    channel_ids: string | string[];
}
export interface AdminUsergroupsAddTeamsArguments extends WebAPICallOptions, TokenOverridable {
    usergroup_id: string;
    team_ids: string | string[];
    auto_provision?: boolean;
}
export interface AdminUsergroupsListChannelsArguments extends WebAPICallOptions, TokenOverridable {
    usergroup_id: string;
    include_num_members?: boolean;
    team_id?: string;
}
export interface AdminUsergroupsRemoveChannelsArguments extends WebAPICallOptions, TokenOverridable {
    usergroup_id: string;
    channel_ids: string | string[];
}
export interface AdminUsersAssignArguments extends WebAPICallOptions, TokenOverridable {
    team_id: string;
    user_id: string;
    is_restricted?: boolean;
    is_ultra_restricted?: boolean;
}
export interface AdminUsersInviteArguments extends WebAPICallOptions, TokenOverridable {
    channel_ids: string;
    email: string;
    team_id: string;
    custom_message?: string;
    guest_expiration_ts?: string;
    is_restricted?: boolean;
    is_ultra_restricted?: boolean;
    real_name?: string;
    resend?: boolean;
}
export interface AdminUsersListArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
    team_id: string;
}
export interface AdminUsersRemoveArguments extends WebAPICallOptions, TokenOverridable {
    team_id: string;
    user_id: string;
}
export interface AdminUsersSetAdminArguments extends WebAPICallOptions, TokenOverridable {
    team_id: string;
    user_id: string;
}
export interface AdminUsersSetExpirationArguments extends WebAPICallOptions, TokenOverridable {
    team_id: string;
    user_id: string;
    expiration_ts: number;
}
export interface AdminUsersSetOwnerArguments extends WebAPICallOptions, TokenOverridable {
    team_id: string;
    user_id: string;
}
export interface AdminUsersSetRegularArguments extends WebAPICallOptions, TokenOverridable {
    team_id: string;
    user_id: string;
}
export interface AdminUsersSessionListArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
    user_id?: string;
    team_id?: string;
}
export interface AdminUsersSessionResetArguments extends WebAPICallOptions, TokenOverridable {
    user_id: string;
    mobile_only?: boolean;
    web_only?: boolean;
}
export interface AdminUsersSessionInvalidateArguments extends WebAPICallOptions, TokenOverridable {
    session_id: string;
    team_id: string;
}
export interface APITestArguments extends WebAPICallOptions {
}
export interface AppsEventAuthorizationsListArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
    event_context: string;
}
export interface AppsUninstallArguments extends WebAPICallOptions {
    client_id: string;
    client_secret: string;
}
export interface AuthRevokeArguments extends WebAPICallOptions, TokenOverridable {
    test: boolean;
}
export interface AuthTeamsListArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
    include_icon?: boolean;
}
export interface AuthTestArguments extends WebAPICallOptions, TokenOverridable {
}
export interface BotsInfoArguments extends WebAPICallOptions, TokenOverridable {
    bot?: string;
    team_id?: string;
}
export interface CallsAddArguments extends WebAPICallOptions, TokenOverridable {
    external_unique_id: string;
    join_url: string;
    created_by?: string;
    date_start?: number;
    desktop_app_join_url?: string;
    external_display_id?: string;
    title?: string;
    users?: CallUser[];
}
export interface CallsEndArguments extends WebAPICallOptions, TokenOverridable {
    id: string;
    duration?: number;
}
export interface CallsInfoArguments extends WebAPICallOptions, TokenOverridable {
    id: string;
}
export interface CallsUpdateArguments extends WebAPICallOptions, TokenOverridable {
    id: string;
    join_url?: string;
    desktop_app_join_url?: string;
    title?: string;
}
export interface CallsParticipantsAddArguments extends WebAPICallOptions, TokenOverridable {
    id: string;
    users: CallUser[];
}
export interface CallsParticipantsRemoveArguments extends WebAPICallOptions, TokenOverridable {
    id: string;
    users: CallUser[];
}
export interface ChannelsArchiveArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
}
export interface ChannelsCreateArguments extends WebAPICallOptions, TokenOverridable {
    name: string;
    validate?: boolean;
    team_id?: string;
}
export interface ChannelsHistoryArguments extends WebAPICallOptions, TokenOverridable, TimelinePaginationEnabled {
    channel: string;
    count?: number;
    unreads?: boolean;
}
export interface ChannelsInfoArguments extends WebAPICallOptions, TokenOverridable, LocaleAware {
    channel: string;
}
export interface ChannelsInviteArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    user: string;
}
export interface ChannelsJoinArguments extends WebAPICallOptions, TokenOverridable {
    name: string;
    validate?: boolean;
}
export interface ChannelsKickArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    user: string;
}
export interface ChannelsLeaveArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
}
export interface ChannelsListArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
    exclude_archived?: boolean;
    exclude_members?: boolean;
    team_id?: string;
}
export interface ChannelsMarkArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    ts: string;
}
export interface ChannelsRenameArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    name: string;
    validate?: boolean;
}
export interface ChannelsRepliesArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    thread_ts: string;
}
export interface ChannelsSetPurposeArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    purpose: string;
}
export interface ChannelsSetTopicArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    topic: string;
}
export interface ChannelsUnarchiveArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
}
export interface ChatDeleteArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    ts: string;
    as_user?: boolean;
}
export interface ChatDeleteScheduledMessageArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    scheduled_message_id: string;
    as_user?: boolean;
}
export interface ChatGetPermalinkArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    message_ts: string;
}
export interface ChatMeMessageArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    text: string;
}
export interface ChatPostEphemeralArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    text: string;
    user: string;
    as_user?: boolean;
    attachments?: MessageAttachment[];
    blocks?: (KnownBlock | Block)[];
    link_names?: boolean;
    parse?: 'full' | 'none';
}
export interface ChatPostMessageArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    text: string;
    as_user?: boolean;
    attachments?: MessageAttachment[];
    blocks?: (KnownBlock | Block)[];
    icon_emoji?: string;
    icon_url?: string;
    link_names?: boolean;
    mrkdwn?: boolean;
    parse?: 'full' | 'none';
    reply_broadcast?: boolean;
    thread_ts?: string;
    unfurl_links?: boolean;
    unfurl_media?: boolean;
    username?: string;
}
export interface ChatScheduleMessageArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    text: string;
    post_at: string;
    as_user?: boolean;
    attachments?: MessageAttachment[];
    blocks?: (KnownBlock | Block)[];
    link_names?: boolean;
    parse?: 'full' | 'none';
    reply_broadcast?: boolean;
    thread_ts?: string;
    unfurl_links?: boolean;
    unfurl_media?: boolean;
    team_id?: string;
}
export interface ChatScheduledMessagesListArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
    channel: string;
    latest: number;
    oldest: number;
}
export interface ChatUnfurlArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    ts: string;
    unfurls: LinkUnfurls;
    user_auth_message?: string;
    user_auth_required?: boolean;
    user_auth_url?: string;
}
export interface ChatUpdateArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    text: string;
    ts: string;
    as_user?: boolean;
    attachments?: MessageAttachment[];
    blocks?: (KnownBlock | Block)[];
    link_names?: boolean;
    parse?: 'full' | 'none';
}
export interface ConversationsArchiveArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
}
export interface ConversationsCloseArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
}
export interface ConversationsCreateArguments extends WebAPICallOptions, TokenOverridable {
    name: string;
    is_private?: boolean;
    team_id?: string;
}
export interface ConversationsHistoryArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled, TimelinePaginationEnabled {
    channel: string;
}
export interface ConversationsInfoArguments extends WebAPICallOptions, TokenOverridable, LocaleAware {
    channel: string;
}
export interface ConversationsInviteArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    users: string;
}
export interface ConversationsJoinArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
}
export interface ConversationsKickArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    user: string;
}
export interface ConversationsLeaveArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
}
export interface ConversationsListArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
    exclude_archived?: boolean;
    types?: string;
    team_id?: string;
}
export interface ConversationsMarkArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    ts: string;
}
export interface ConversationsMembersArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
    channel: string;
}
export interface ConversationsOpenArguments extends WebAPICallOptions, TokenOverridable {
    channel?: string;
    users?: string;
    return_im?: boolean;
}
export interface ConversationsRenameArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    name: string;
}
export interface ConversationsRepliesArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled, TimelinePaginationEnabled {
    channel: string;
    ts: string;
}
export interface ConversationsSetPurposeArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    purpose: string;
}
export interface ConversationsSetTopicArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    topic: string;
}
export interface ConversationsUnarchiveArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
}
export interface DialogOpenArguments extends WebAPICallOptions, TokenOverridable {
    trigger_id: string;
    dialog: Dialog;
}
export interface DndEndDndArguments extends WebAPICallOptions, TokenOverridable {
}
export interface DndEndSnoozeArguments extends WebAPICallOptions, TokenOverridable {
}
export interface DndInfoArguments extends WebAPICallOptions, TokenOverridable {
    user: string;
}
export interface DndSetSnoozeArguments extends WebAPICallOptions, TokenOverridable {
    num_minutes: number;
}
export interface DndTeamInfoArguments extends WebAPICallOptions, TokenOverridable {
    users?: string;
}
export interface EmojiListArguments extends WebAPICallOptions, TokenOverridable {
}
export interface FilesDeleteArguments extends WebAPICallOptions, TokenOverridable {
    file: string;
}
export interface FilesInfoArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
    file: string;
    count?: number;
    page?: number;
}
export interface FilesListArguments extends WebAPICallOptions, TokenOverridable, TraditionalPagingEnabled {
    channel?: string;
    user?: string;
    ts_from?: string;
    ts_to?: string;
    types?: string;
    team_id?: string;
}
export interface FilesRevokePublicURLArguments extends WebAPICallOptions, TokenOverridable {
    file: string;
}
export interface FilesSharedPublicURLArguments extends WebAPICallOptions, TokenOverridable {
    file: string;
}
export interface FilesUploadArguments extends WebAPICallOptions, TokenOverridable {
    channels?: string;
    content?: string;
    file?: Buffer | Stream;
    filename?: string;
    filetype?: string;
    initial_comment?: string;
    title?: string;
    thread_ts?: string;
}
export interface FilesCommentsDeleteArguments extends WebAPICallOptions, TokenOverridable {
    file: string;
    id: string;
}
export interface FilesRemoteInfoArguments extends WebAPICallOptions, TokenOverridable {
    file?: string;
    external_id?: string;
}
export interface FilesRemoteListArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
    ts_from?: string;
    ts_to?: string;
    channel?: string;
}
export interface FilesRemoteAddArguments extends WebAPICallOptions, TokenOverridable {
    title: string;
    external_url: string;
    external_id: string;
    filetype: string;
    preview_image?: Buffer | Stream;
    indexable_file_contents?: Buffer | Stream;
}
export interface FilesRemoteUpdateArguments extends WebAPICallOptions, TokenOverridable {
    title?: string;
    external_url?: string;
    filetype?: string;
    preview_image?: Buffer | Stream;
    indexable_file_contents?: Buffer | Stream;
    file?: string;
    external_id?: string;
}
export interface FilesRemoteRemoveArguments extends WebAPICallOptions, TokenOverridable {
    file?: string;
    external_id?: string;
}
export interface FilesRemoteShareArguments extends WebAPICallOptions, TokenOverridable {
    channels: string;
    file?: string;
    external_id?: string;
}
export interface GroupsArchiveArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
}
export interface GroupsCreateArguments extends WebAPICallOptions, TokenOverridable {
    name: string;
    validate?: boolean;
    team_id?: string;
}
export interface GroupsCreateChildArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
}
export interface GroupsHistoryArguments extends WebAPICallOptions, TokenOverridable, TimelinePaginationEnabled {
    channel: string;
    unreads?: boolean;
    count?: number;
}
export interface GroupsInfoArguments extends WebAPICallOptions, TokenOverridable, LocaleAware {
    channel: string;
}
export interface GroupsInviteArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    user: string;
}
export interface GroupsKickArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    user: string;
}
export interface GroupsLeaveArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
}
export interface GroupsListArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
    exclude_archived?: boolean;
    exclude_members?: boolean;
    team_id?: string;
}
export interface GroupsMarkArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    ts: string;
}
export interface GroupsOpenArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
}
export interface GroupsRenameArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    name: string;
    validate?: boolean;
}
export interface GroupsRepliesArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    thread_ts: boolean;
}
export interface GroupsSetPurposeArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    purpose: string;
}
export interface GroupsSetTopicArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    topic: string;
}
export interface GroupsUnarchiveArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
}
export interface IMCloseArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
}
export interface IMHistoryArguments extends WebAPICallOptions, TokenOverridable, TimelinePaginationEnabled {
    channel: string;
    count?: number;
    unreads?: boolean;
}
export interface IMListArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
}
export interface IMMarkArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    ts: string;
}
export interface IMOpenArguments extends WebAPICallOptions, TokenOverridable, LocaleAware {
    user: string;
    return_im?: boolean;
}
export interface IMRepliesArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    thread_ts?: string;
}
export interface MigrationExchangeArguments extends WebAPICallOptions, TokenOverridable {
    users: string;
    to_old?: boolean;
    team_id?: string;
}
export interface MPIMCloseArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
}
export interface MPIMHistoryArguments extends WebAPICallOptions, TokenOverridable, TimelinePaginationEnabled {
    channel: string;
    count?: number;
    unreads?: boolean;
}
export interface MPIMListArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
}
export interface MPIMMarkArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    ts: string;
}
export interface MPIMOpenArguments extends WebAPICallOptions, TokenOverridable {
    users: string;
}
export interface MPIMRepliesArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    thread_ts: string;
}
export interface OAuthAccessArguments extends WebAPICallOptions {
    client_id: string;
    client_secret: string;
    code: string;
    redirect_uri?: string;
    single_channel?: string;
}
export interface OAuthV2AccessArguments extends WebAPICallOptions {
    client_id: string;
    client_secret: string;
    code: string;
    redirect_uri?: string;
}
export interface PinsAddArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    file?: string;
    file_comment?: string;
    timestamp?: string;
}
export interface PinsListArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
}
export interface PinsRemoveArguments extends WebAPICallOptions, TokenOverridable {
    channel: string;
    file?: string;
    file_comment?: string;
    timestamp?: string;
}
export interface ReactionsAddArguments extends WebAPICallOptions, TokenOverridable {
    name: string;
    channel?: string;
    timestamp?: string;
    file?: string;
    file_comment?: string;
}
export interface ReactionsGetArguments extends WebAPICallOptions, TokenOverridable {
    full?: boolean;
    channel?: string;
    timestamp?: string;
    file?: string;
    file_comment?: string;
}
export interface ReactionsListArguments extends WebAPICallOptions, TokenOverridable, TraditionalPagingEnabled, CursorPaginationEnabled {
    user?: string;
    full?: boolean;
    team_id?: string;
}
export interface ReactionsRemoveArguments extends WebAPICallOptions, TokenOverridable {
    name: string;
    channel?: string;
    timestamp?: string;
    file?: string;
    file_comment?: string;
}
export interface RemindersAddArguments extends WebAPICallOptions, TokenOverridable {
    text: string;
    time: string | number;
    user?: string;
}
export interface RemindersCompleteArguments extends WebAPICallOptions, TokenOverridable {
    reminder: string;
}
export interface RemindersDeleteArguments extends WebAPICallOptions, TokenOverridable {
    reminder: string;
}
export interface RemindersInfoArguments extends WebAPICallOptions, TokenOverridable {
    reminder: string;
}
export interface RemindersListArguments extends WebAPICallOptions, TokenOverridable {
}
export interface RTMConnectArguments extends WebAPICallOptions, TokenOverridable {
    batch_presence_aware?: boolean;
    presence_sub?: boolean;
}
export interface RTMStartArguments extends WebAPICallOptions, TokenOverridable, LocaleAware {
    batch_presence_aware?: boolean;
    mpim_aware?: boolean;
    no_latest?: '0' | '1';
    no_unreads?: string;
    presence_sub?: boolean;
    simple_latest?: boolean;
}
export interface SearchAllArguments extends WebAPICallOptions, TokenOverridable, TraditionalPagingEnabled, Searchable {
}
export interface SearchFilesArguments extends WebAPICallOptions, TokenOverridable, TraditionalPagingEnabled, Searchable {
}
export interface SearchMessagesArguments extends WebAPICallOptions, TokenOverridable, TraditionalPagingEnabled, Searchable {
}
export interface StarsAddArguments extends WebAPICallOptions, TokenOverridable {
    channel?: string;
    timestamp?: string;
    file?: string;
    file_comment?: string;
}
export interface StarsListArguments extends WebAPICallOptions, TokenOverridable, TraditionalPagingEnabled, CursorPaginationEnabled {
}
export interface StarsRemoveArguments extends WebAPICallOptions, TokenOverridable {
    channel?: string;
    timestamp?: string;
    file?: string;
    file_comment?: string;
}
export interface TeamAccessLogsArguments extends WebAPICallOptions, TokenOverridable {
    before?: number;
    count?: number;
    page?: number;
    team_id?: string;
}
export interface TeamBillableInfoArguments extends WebAPICallOptions, TokenOverridable {
    user?: string;
    team_id?: string;
}
export interface TeamInfoArguments extends WebAPICallOptions, TokenOverridable {
}
export interface TeamIntegrationLogsArguments extends WebAPICallOptions, TokenOverridable {
    app_id?: string;
    change_type?: string;
    count?: number;
    page?: number;
    service_id?: string;
    user?: string;
    team_id?: string;
}
export interface TeamProfileGetArguments extends WebAPICallOptions, TokenOverridable {
    visibility?: 'all' | 'visible' | 'hidden';
    team_id?: string;
}
export interface UsergroupsCreateArguments extends WebAPICallOptions, TokenOverridable {
    name: string;
    channels?: string;
    description?: string;
    handle?: string;
    include_count?: boolean;
}
export interface UsergroupsDisableArguments extends WebAPICallOptions, TokenOverridable {
    usergroup: string;
    include_count?: boolean;
}
export interface UsergroupsEnableArguments extends WebAPICallOptions, TokenOverridable {
    usergroup: string;
    include_count?: boolean;
}
export interface UsergroupsListArguments extends WebAPICallOptions, TokenOverridable {
    include_count?: boolean;
    include_disabled?: boolean;
    include_users?: boolean;
}
export interface UsergroupsUpdateArguments extends WebAPICallOptions, TokenOverridable {
    usergroup: string;
    channels?: string;
    description?: string;
    handle?: string;
    include_count?: boolean;
    name?: string;
}
export interface UsergroupsUsersListArguments extends WebAPICallOptions, TokenOverridable {
    usergroup: string;
    include_disabled?: boolean;
}
export interface UsergroupsUsersUpdateArguments extends WebAPICallOptions, TokenOverridable {
    usergroup: string;
    users: string;
    include_count?: boolean;
}
export interface UsersConversationsArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled {
    exclude_archived?: boolean;
    types?: string;
    user?: string;
    team_id?: string;
}
export interface UsersDeletePhotoArguments extends WebAPICallOptions, TokenOverridable {
}
export interface UsersGetPresenceArguments extends WebAPICallOptions, TokenOverridable {
    user: string;
}
export interface UsersIdentityArguments extends WebAPICallOptions, TokenOverridable {
}
export interface UsersInfoArguments extends WebAPICallOptions, TokenOverridable, LocaleAware {
    user: string;
}
export interface UsersListArguments extends WebAPICallOptions, TokenOverridable, CursorPaginationEnabled, LocaleAware {
    presence?: boolean;
    team_id?: string;
}
export interface UsersLookupByEmailArguments extends WebAPICallOptions, TokenOverridable {
    email: string;
}
export interface UsersSetPhotoArguments extends WebAPICallOptions, TokenOverridable {
    image: Buffer | Stream;
    crop_w?: number;
    crop_x?: number;
    crop_y?: number;
}
export interface UsersSetPresenceArguments extends WebAPICallOptions, TokenOverridable {
    presence: 'auto' | 'away';
}
export interface UsersProfileGetArguments extends WebAPICallOptions, TokenOverridable {
    include_labels?: boolean;
    user?: string;
}
export interface UsersProfileSetArguments extends WebAPICallOptions, TokenOverridable {
    profile?: string;
    user?: string;
    name?: string;
    value?: string;
}
export interface ViewsOpenArguments extends WebAPICallOptions, TokenOverridable {
    trigger_id: string;
    view: View;
}
export interface ViewsPushArguments extends WebAPICallOptions, TokenOverridable {
    trigger_id: string;
    view: View;
}
export interface ViewsPublishArguments extends WebAPICallOptions, TokenOverridable {
    user_id: string;
    view: View;
    hash?: string;
}
export interface ViewsUpdateArguments extends WebAPICallOptions, TokenOverridable {
    view_id?: string;
    view: View;
    external_id?: string;
    hash?: string;
}
export interface WorkflowsStepCompletedArguments extends WebAPICallOptions, TokenOverridable {
    workflow_step_execute_id: string;
    outputs?: object;
}
export interface WorkflowsStepFailedArguments extends WebAPICallOptions, TokenOverridable {
    workflow_step_execute_id: string;
    error: {
        message: string;
    };
}
export interface WorkflowsUpdateStepArguments extends WebAPICallOptions, TokenOverridable {
    workflow_step_edit_id: string;
    inputs?: object;
    outputs?: {
        type: string;
        name: string;
        label: string;
    }[];
}
export * from '@slack/types';
//# sourceMappingURL=methods.d.ts.map